==> vtk-6.3.0-5-armv6h.pkg.tar.xz: vtk/vtkProp3DButtonRepresentation.java <==
// java wrapper for vtkProp3DButtonRepresentation object
//

package vtk;
import vtk.*;

public class vtkProp3DButtonRepresentation extends vtkButtonRepresentation
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetButtonProp_2(int id0,vtkProp3D id1);
  public void SetButtonProp(int id0,vtkProp3D id1)
    { SetButtonProp_2(id0,id1); }

  private native long GetButtonProp_3(int id0);
  public vtkProp3D GetButtonProp(int id0) {
    long temp = GetButtonProp_3(id0);

    if (temp == 0) return null;
    return (vtkProp3D)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetFollowCamera_4(int id0);
  public void SetFollowCamera(int id0)
    { SetFollowCamera_4(id0); }

  private native int GetFollowCamera_5();
  public int GetFollowCamera()
    { return GetFollowCamera_5(); }

  private native void FollowCameraOn_6();
  public void FollowCameraOn()
    { FollowCameraOn_6(); }

  private native void FollowCameraOff_7();
  public void FollowCameraOff()
    { FollowCameraOff_7(); }

  private native void SetState_8(int id0);
  public void SetState(int id0)
    { SetState_8(id0); }

  private native int ComputeInteractionState_9(int id0,int id1,int id2);
  public int ComputeInteractionState(int id0,int id1,int id2)
    { return ComputeInteractionState_9(id0,id1,id2); }

  private native void BuildRepresentation_10();
  public void BuildRepresentation()
    { BuildRepresentation_10(); }

  private native void PlaceWidget_11(double id0[]);
  public void PlaceWidget(double id0[])
    { PlaceWidget_11(id0); }

  private native void ShallowCopy_12(vtkProp id0);
  public void ShallowCopy(vtkProp id0)
    { ShallowCopy_12(id0); }

  private native void GetActors_13(vtkPropCollection id0);
  public void GetActors(vtkPropCollection id0)
    { GetActors_13(id0); }

  private native void ReleaseGraphicsResources_14(vtkWindow id0);
  public void ReleaseGraphicsResources(vtkWindow id0)
    { ReleaseGraphicsResources_14(id0); }

  private native int RenderOpaqueGeometry_15(vtkViewport id0);
  public int RenderOpaqueGeometry(vtkViewport id0)
    { return RenderOpaqueGeometry_15(id0); }

  private native int RenderVolumetricGeometry_16(vtkViewport id0);
  public int RenderVolumetricGeometry(vtkViewport id0)
    { return RenderVolumetricGeometry_16(id0); }

  private native int RenderTranslucentPolygonalGeometry_17(vtkViewport id0);
  public int RenderTranslucentPolygonalGeometry(vtkViewport id0)
    { return RenderTranslucentPolygonalGeometry_17(id0); }

  private native int HasTranslucentPolygonalGeometry_18();
  public int HasTranslucentPolygonalGeometry()
    { return HasTranslucentPolygonalGeometry_18(); }

  public vtkProp3DButtonRepresentation() { super(); }

  public vtkProp3DButtonRepresentation(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-14-armv6h.pkg.tar.xz: vtk/vtkProp3DButtonRepresentation.java <==
// java wrapper for vtkProp3DButtonRepresentation object
//

package vtk;
import vtk.*;

public class vtkProp3DButtonRepresentation extends vtkButtonRepresentation
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetButtonProp_2(int id0,vtkProp3D id1);
  public void SetButtonProp(int id0,vtkProp3D id1)
    { SetButtonProp_2(id0,id1); }

  private native long GetButtonProp_3(int id0);
  public vtkProp3D GetButtonProp(int id0) {
    long temp = GetButtonProp_3(id0);

    if (temp == 0) return null;
    return (vtkProp3D)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetFollowCamera_4(int id0);
  public void SetFollowCamera(int id0)
    { SetFollowCamera_4(id0); }

  private native int GetFollowCamera_5();
  public int GetFollowCamera()
    { return GetFollowCamera_5(); }

  private native void FollowCameraOn_6();
  public void FollowCameraOn()
    { FollowCameraOn_6(); }

  private native void FollowCameraOff_7();
  public void FollowCameraOff()
    { FollowCameraOff_7(); }

  private native void SetState_8(int id0);
  public void SetState(int id0)
    { SetState_8(id0); }

  private native int ComputeInteractionState_9(int id0,int id1,int id2);
  public int ComputeInteractionState(int id0,int id1,int id2)
    { return ComputeInteractionState_9(id0,id1,id2); }

  private native void BuildRepresentation_10();
  public void BuildRepresentation()
    { BuildRepresentation_10(); }

  private native void PlaceWidget_11(double id0[]);
  public void PlaceWidget(double id0[])
    { PlaceWidget_11(id0); }

  private native void ShallowCopy_12(vtkProp id0);
  public void ShallowCopy(vtkProp id0)
    { ShallowCopy_12(id0); }

  private native void GetActors_13(vtkPropCollection id0);
  public void GetActors(vtkPropCollection id0)
    { GetActors_13(id0); }

  private native void ReleaseGraphicsResources_14(vtkWindow id0);
  public void ReleaseGraphicsResources(vtkWindow id0)
    { ReleaseGraphicsResources_14(id0); }

  private native int RenderOpaqueGeometry_15(vtkViewport id0);
  public int RenderOpaqueGeometry(vtkViewport id0)
    { return RenderOpaqueGeometry_15(id0); }

  private native int RenderVolumetricGeometry_16(vtkViewport id0);
  public int RenderVolumetricGeometry(vtkViewport id0)
    { return RenderVolumetricGeometry_16(id0); }

  private native int RenderTranslucentPolygonalGeometry_17(vtkViewport id0);
  public int RenderTranslucentPolygonalGeometry(vtkViewport id0)
    { return RenderTranslucentPolygonalGeometry_17(id0); }

  private native int HasTranslucentPolygonalGeometry_18();
  public int HasTranslucentPolygonalGeometry()
    { return HasTranslucentPolygonalGeometry_18(); }

  private native void RegisterPickers_19();
  public void RegisterPickers()
    { RegisterPickers_19(); }

  public vtkProp3DButtonRepresentation() { super(); }

  public vtkProp3DButtonRepresentation(long id) { super(id); }
  public native long   VTKInit();

}
